@@ -23,10 +23,10 @@ def init_parser_run(subparsers):
     )
     return sub_parser_run
 
-
 def main_run(extra_args) -> enum.IntEnum:
     capture_message("start to run")
     # keep compatibility with v2
+    flag_dict={}
     extra_args = ensure_cli_args(extra_args)
 
     tests_path_list = []
@@ -124,15 +124,13 @@ def main():
     elif sys.argv[1] == "make":
         main_make(args.testcase_path)
 
-
+# hrun testcases/gateway_api/app_gateway/test --clean-alluredir --alluredir=./allure/results --env=test1 -s -v -n auto --toexcel=/opt/自动化测试.xlsx
+# hrun testcases/gateway_api/app_gateway/test --clean-alluredir --alluredir=./allure/results --env=test1 -s --toexcel=/opt/自动化测试.xlsx
 def parse_diff():
     for i in range(1, len(sys.argv)):
         if "--diff" in sys.argv[i]:
             content = str(sys.argv[i].split("=")[1]).split(",")
             globalvar.set_value('diff', content)
-        if "--env" in sys.argv[i]:
-            content = str(sys.argv[i].split("=")[1]).split(",")
-            globalvar.set_value('env', content)
 
 
 def main_hrun_alias():
