@@ -489,6 +489,9 @@ def load_project_meta(test_path: Text, reload: bool = False) -> ProjectMeta:
     if not test_path:
         return project_meta
 
+    if sys.platform.startswith("win"):
+        test_path = test_path.replace("/", "\\")
+
     debugtalk_path, custom_path, project_root_directory = locate_project_root_directory(test_path)
 
     # add project RootDir to sys.path
