@@ -4,7 +4,6 @@ import os
 import re
 from typing import Any, Set, Text, Callable, List, Dict
 
-import demjson
 from loguru import logger
 from sentry_sdk import capture_exception
 
@@ -26,6 +25,7 @@ function_regex_compile2 = re.compile(r"\$\{(\w+)\(([\$\S\w\s=,]*?)\)\}")
 
 suffix_regex_compile1 = r'\[\'(.*?)\'\]'
 suffix_regex_compile2 = r"\[(.*?)\]"
+suffix_regex_compile = re.compile(r"(\[\'.*?\'\]|\[.*?\])")
 suffix = []
 suffix2 = []
 
@@ -390,6 +390,8 @@ def parse_string(
             var_value = get_mapping_variable(var_name, variables_mapping)
             global suffix
             global suffix2
+            # suffix_var = suffix_regex_compile.findall(raw_string)
+            # return eval(str(var_value)+"".join(parse_data(suffix_var, variables_mapping, functions_mapping)))
             suffix_re = re.findall(var_name + suffix_regex_compile1, raw_string)
             if not suffix_re:
                 suffix_re = re.findall(var_name + suffix_regex_compile2, str(raw_string))
@@ -401,7 +403,7 @@ def parse_string(
                 if var_value is None:
                     return var_value
                 if not isinstance(var_value, Text) and not isinstance(var_value, int):
-                    var_value = var_value[suffix]
+                    var_value = var_value[parse_data(suffix, variables_mapping, functions_mapping)]
                 full_string = remove_bracket_first(raw_string)
                 raw_string = full_string
 
