@@ -328,7 +328,7 @@ class HttpRunner(object):
                         call = "无"
                 content = {"dir": self.config.path, "base_url": self.__config.base_url, "url": url_path,
                            "method": method, "name": self.config.name,
-                           "location": location, "call": call, "curl": a.curl}
+                           "location": location, "call": call, "response": resp_obj.body, "curl": a.curl}
                 write_excel(content, globalvar.get_value("toexcel"))
 
         return step_data
