@@ -82,6 +82,10 @@ class Config(object):
         self.__datasource["mongo"] = config
         return self
 
+    def es(self, config: Union[Text, Dict]) -> "Config":
+        self.__datasource["es"] = config
+        return self
+
     def perform(self) -> TConfig:
         return TConfig(
             name=self.__name,
@@ -204,6 +208,21 @@ class StepRequestValidation(object):
                 self.__step_context.teardown.append("mongo:" + str(mongo))
         return self
 
+    def teardown_es(self, es: Union[Text, List], assign_var_name: Text = None) -> "StepRequestValidation":
+        if isinstance(es, List):
+            # 指定环境场景
+            db, cli = es[0], es[1]
+            if assign_var_name is not None:
+                self.__step_context.teardown.append("es:" + str(cli) + "&&db:" + str(db) + "##" + assign_var_name)
+            else:
+                self.__step_context.teardown.append("es:" + str(cli) + "&&db:" + str(db))
+        else:
+            if assign_var_name is not None:
+                self.__step_context.teardown.append("es:" + str(es) + "##" + assign_var_name)
+            else:
+                self.__step_context.teardown.append("es:" + str(es))
+        return self
+
     def teardown_cmd(self, command: Text) -> "StepRequestValidation":
         """ 在接口执行之后执行cmd命令
 
@@ -488,6 +507,19 @@ class StepRequestExtraction(object):
         self.__extract__("mongo", var, var_name)
         return self
 
+    def with_es(self, var: Text, var_name: Text) -> "StepRequestExtraction":
+        """ 提取es数据
+
+        Args:
+            var: es指令
+            var_name: 存储的变量名 后续通过$引用
+
+        Returns:self
+
+        """
+        self.__extract__("es", var, var_name)
+        return self
+
     # def with_regex(self):
     #     # TODO: extract response html with regex
     #     pass
@@ -709,6 +741,21 @@ class RunRequest(object):
                 self.__step_context.setup.append("mongo:" + str(mongo))
         return self
 
+    def setup_es(self, es: Union[Text, List], assign_var_name: Text = None) -> "RunRequest":
+        if isinstance(es, List):
+            # 指定环境场景
+            db, cli = es[0], es[1]
+            if assign_var_name is not None:
+                self.__step_context.setup.append("es:" + str(cli) + "&&db:" + str(db) + "##" + assign_var_name)
+            else:
+                self.__step_context.setup.append("es:" + str(cli) + "&&db:" + str(db))
+        else:
+            if assign_var_name is not None:
+                self.__step_context.setup.append("es:" + str(es) + "##" + assign_var_name)
+            else:
+                self.__step_context.setup.append("es:" + str(es))
+        return self
+
     def setup_cmd(self, command: Text) -> "RunRequest":
         """ 在接口执行之前执行cmd命令
 
